@@ -27,7 +27,7 @@ class HttpClient:
             Passed as the params parameter of the requests.get request.
         
         """
-        res = requests.get(self.base_url + url, params=params, headers=self.headers)
+        res = requests.get(self.base_url + url, params=params, headers=self.headers, verify=False)
         res.raise_for_status()
         return res.json()
 
@@ -44,7 +44,7 @@ class HttpClient:
             Passed as the data parameter of the requests.post request.
         """
         res = requests.post(
-            self.base_url + url, params=params, json=data, headers=self.headers
+            self.base_url + url, params=params, json=data, headers=self.headers, verify=False
         )
         res.raise_for_status()
         return res.json()
\ No newline at end of file
